'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = RecordTypeInput;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _PrefixFilteringDropdownMenuInput = require('./PrefixFilteringDropdownMenuInput');

var _PrefixFilteringDropdownMenuInput2 = _interopRequireDefault(_PrefixFilteringDropdownMenuInput);

var _withLabeledOptions = require('../enhancers/withLabeledOptions');

var _withLabeledOptions2 = _interopRequireDefault(_withLabeledOptions);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var PrefixFilteringDropdownMenuInput = (0, _withLabeledOptions2.default)(_PrefixFilteringDropdownMenuInput2.default);

var propTypes = {
  formatRecordTypeLabel: _react.PropTypes.func,
  recordTypes: _react.PropTypes.object,
  serviceTypeOrder: _react.PropTypes.object,
  value: _react.PropTypes.string
};

var defaultProps = {
  formatRecordTypeLabel: function formatRecordTypeLabel(name, config) {
    var messages = config.messages;

    if (messages) {
      return messages.record.collectionName.defaultMessage;
    }

    return name;
  },
  recordTypes: {},
  serviceTypeOrder: {
    utility: 0,
    object: 1,
    procedure: 2,
    authority: 3
  }
};

function RecordTypeInput(props) {
  var formatRecordTypeLabel = props.formatRecordTypeLabel,
      recordTypes = props.recordTypes,
      serviceTypeOrder = props.serviceTypeOrder,
      recordTypeValue = props.value,
      remainingProps = _objectWithoutProperties(props, ['formatRecordTypeLabel', 'recordTypes', 'serviceTypeOrder', 'value']);

  var sortedRecordTypeNames = Object.keys(recordTypes).sort(function (nameA, nameB) {
    var configA = recordTypes[nameA];
    var configB = recordTypes[nameB];

    // Primary sort by service type

    var serviceTypeA = configA.serviceConfig.serviceType;
    var serviceTypeB = configB.serviceConfig.serviceType;

    if (serviceTypeA !== serviceTypeB) {
      var serviceTypeOrderA = serviceTypeOrder[serviceTypeA];
      var serviceTypeOrderB = serviceTypeOrder[serviceTypeB];

      if (isNaN(serviceTypeOrderA)) {
        serviceTypeOrderA = Number.MAX_VALUE;
      }

      if (isNaN(serviceTypeOrderB)) {
        serviceTypeOrderB = Number.MAX_VALUE;
      }

      if (serviceTypeOrderA !== serviceTypeOrderB) {
        return serviceTypeOrderA > serviceTypeOrderB ? 1 : -1;
      }
    }

    // Secondary sort by sortOrder

    var sortOrderA = configA.sortOrder;
    var sortOrderB = configB.sortOrder;

    if (typeof sortOrderA !== 'number') {
      sortOrderA = Number.MAX_VALUE;
    }

    if (typeof sortOrderB !== 'number') {
      sortOrderB = Number.MAX_VALUE;
    }

    if (sortOrderA !== sortOrderB) {
      return sortOrderA > sortOrderB ? 1 : -1;
    }

    // Final sort by label

    var labelA = formatRecordTypeLabel(nameA, configA);
    var labelB = formatRecordTypeLabel(nameB, configB);

    // FIXME: This should be locale aware
    return labelA.localeCompare(labelB);
  });

  var options = sortedRecordTypeNames.map(function (name, index) {
    var recordType = recordTypes[name];
    var prevRecordType = index === 0 ? null : recordTypes[sortedRecordTypeNames[index - 1]];

    return {
      value: name,
      label: formatRecordTypeLabel(name, recordType),
      startGroup: !prevRecordType || recordType.serviceConfig.serviceType !== prevRecordType.serviceConfig.serviceType
    };
  });

  var value = recordTypeValue;

  if (!value) {
    for (var i = 0; i < sortedRecordTypeNames.length; i += 1) {
      var recordTypeName = sortedRecordTypeNames[i];
      var recordType = recordTypes[recordTypeName];

      if (recordType.defaultForSearch) {
        value = recordTypeName;
        break;
      }
    }

    if (!value && options.length > 0) {
      value = options[0].value;
    }
  }

  return _react2.default.createElement(PrefixFilteringDropdownMenuInput, _extends({
    blankable: false,
    options: options,
    value: value
  }, remainingProps));
}

RecordTypeInput.propTypes = propTypes;
RecordTypeInput.defaultProps = defaultProps;