'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = VocabularyInput;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _PrefixFilteringDropdownMenuInput = require('./PrefixFilteringDropdownMenuInput');

var _PrefixFilteringDropdownMenuInput2 = _interopRequireDefault(_PrefixFilteringDropdownMenuInput);

var _withLabeledOptions = require('../enhancers/withLabeledOptions');

var _withLabeledOptions2 = _interopRequireDefault(_withLabeledOptions);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var PrefixFilteringDropdownMenuInput = (0, _withLabeledOptions2.default)(_PrefixFilteringDropdownMenuInput2.default);

var propTypes = {
  formatVocabularyLabel: _react.PropTypes.func,
  recordTypes: _react.PropTypes.object,
  recordType: _react.PropTypes.string,
  value: _react.PropTypes.string,
  vocabularyTypeOrder: _react.PropTypes.object
};

var defaultProps = {
  formatVocabularyLabel: function formatVocabularyLabel(name, config) {
    var messages = config.messages;

    if (messages) {
      return messages.name.defaultMessage;
    }

    return name;
  },
  vocabularyTypeOrder: {
    all: 0
  }
};

function VocabularyInput(props) {
  var formatVocabularyLabel = props.formatVocabularyLabel,
      recordTypes = props.recordTypes,
      recordType = props.recordType,
      vocabularyTypeOrder = props.vocabularyTypeOrder,
      vocabularyValue = props.value,
      remainingProps = _objectWithoutProperties(props, ['formatVocabularyLabel', 'recordTypes', 'recordType', 'vocabularyTypeOrder', 'value']);

  if (!recordType || !recordTypes[recordType] || !recordTypes[recordType].vocabularies) {
    return null;
  }

  var vocabularies = recordTypes[recordType].vocabularies;

  var sortedVocabularyNames = Object.keys(vocabularies).sort(function (nameA, nameB) {
    var configA = vocabularies[nameA];
    var configB = vocabularies[nameB];

    // Primary sort by group

    var vocabularyTypeA = configA.type;
    var vocabularyTypeB = configB.type;

    if (vocabularyTypeA !== vocabularyTypeB) {
      var vocabularyTypeOrderA = vocabularyTypeOrder[vocabularyTypeA];
      var vocabularyTypeOrderB = vocabularyTypeOrder[vocabularyTypeB];

      if (isNaN(vocabularyTypeOrderA)) {
        vocabularyTypeOrderA = Number.MAX_VALUE;
      }

      if (isNaN(vocabularyTypeOrderB)) {
        vocabularyTypeOrderB = Number.MAX_VALUE;
      }

      if (vocabularyTypeOrderA !== vocabularyTypeOrderB) {
        return vocabularyTypeOrderA > vocabularyTypeOrderB ? 1 : -1;
      }
    }

    // Secondary sort by sortOrder

    var sortOrderA = configA.sortOrder;
    var sortOrderB = configB.sortOrder;

    if (typeof sortOrderA !== 'number') {
      sortOrderA = Number.MAX_VALUE;
    }

    if (typeof sortOrderB !== 'number') {
      sortOrderB = Number.MAX_VALUE;
    }

    if (sortOrderA !== sortOrderB) {
      return sortOrderA > sortOrderB ? 1 : -1;
    }

    // Final sort by label

    var labelA = formatVocabularyLabel(nameA, configA);
    var labelB = formatVocabularyLabel(nameB, configB);

    // FIXME: This should be locale aware
    return labelA.localeCompare(labelB);
  });

  var options = sortedVocabularyNames.map(function (name, index) {
    var vocabulary = vocabularies[name];
    var prevVocabulary = index === 0 ? null : vocabularies[sortedVocabularyNames[index - 1]];

    return {
      value: name,
      label: formatVocabularyLabel(name, vocabulary),
      startGroup: !prevVocabulary || vocabulary.type !== prevVocabulary.type
    };
  });

  var value = vocabularyValue;

  if (!value) {
    for (var i = 0; i < sortedVocabularyNames.length; i += 1) {
      var vocabularyName = sortedVocabularyNames[i];
      var vocabulary = vocabularies[vocabularyName];

      if (vocabulary.defaultForSearch) {
        value = vocabularyName;
        break;
      }
    }

    if (!value && options.length > 0) {
      value = options[0].value;
    }
  }

  return _react2.default.createElement(PrefixFilteringDropdownMenuInput, _extends({
    blankable: false,
    options: options,
    value: value
  }, remainingProps));
}

VocabularyInput.propTypes = propTypes;
VocabularyInput.defaultProps = defaultProps;